<?php

/************************************************************
 * $File: //depot/povray/tools/wiki-docgen/getWikiPages.php $
 * $Revision: #10 $
 * $Change: 5774 $
 * $DateTime: 2013/02/02 06:52:00 $
 * $Author: jholsenback $
 ***********************************************************/

require_once ("common.php");
require_once ("utilities.php");

ini_set("display_errors", "stdout");

// initialize
$Error = "";
$Test = "";
$Space = " ";
$Unbar = "_";

$Args = $_SERVER['argv'];

/* Process command-line arguments, and set a few things based on the package
   being produced. */

switch (count ($Args)) {
	case 2:
		switch ($Args[1]) {
			case "-ow":
				$FileBrand = "win";
				$DocSetPageTitle = array (
					"win" => "Windows_Table_of_Contents",
					"tut" => "Tutorial_Table_of_Contents",
					"ref" => "Reference_Table_of_Contents"
					);
				$Chapters = array (
					"win",
					"tut",
					"ref"
					);
				$Platform = "Windows";
			break;
			case "-om":
				$FileBrand = "mac";
				$DocSetPageTitle = array (
					"mac" => "Mac_OS_Table_of_Contents",
					"tut" => "Tutorial_Table_of_Contents",
					"ref" => "Reference_Table_of_Contents"
					);
				$Chapters = array (
					"mac",
					"tut",
					"ref"
					);
				$Platform = "Mac OS";
			break;
			case "-ou":
				$FileBrand = "unx";
				$DocSetPageTitle = array (
					"win" => "Unix_Table_of_Contents",
					"tut" => "Tutorial_Table_of_Contents",
					"ref" => "Reference_Table_of_Contents"
					);
				$Chapters = array (
					"unx",
					"tut",
					"ref"
					);
				$Platform = "Unix";
			break;
			default:
				$Error = "yes";
			break;
			}
	break;
	default:
		$Error = "yes";
	break;
	}

if ($Error) {
	printf ("\nUsage: getWikiPages.php -ow | -om | -ou\n\n");
	exit (1);
	}

function buildTitlePageArray ($BaseName, $Section, $Sections) {
$i = 0;
while ( $i < $Sections ) {
	if ( $i == 0 ) {
		$PageTitle[$i] = $BaseName."_".$Section;
		}
	else {
		$PageTitle[$i] = $BaseName."_".$Section.".".$i;
		}
	$i++;
	}
return $PageTitle;
}

function flipRefPageName ($RefPageEntry) {
$Space = " ";
$Unbar = "_";
switch ($RefPageEntry) {
	case "Rad_def.inc":
		// do nothing
	break;
	case "Shapes_old.inc":
		// do nothing
	break;
	case "Glass_old.inc":
		// do nothing
	break;
	default:
		$RefPageEntry = preg_replace ("/$Unbar/", $Space, $RefPageEntry);
	break;
	}
return $RefPageEntry;
}
// Begin main execution here
// -------------------------

$BaseName = array (
	"tut" => "Tutorial_Section",
	"win" => "Windows_Section",
	"mac" => "Mac_OS_Section",
	"unx" => "Unix_Section"
	);

// Section and sub-section information
$Sections =	array (
	"tut" => array ("s1" => 2, "s2" => 3, "s3" => 11, "s4" => 1, "s5" => 2), 
	"win" => array ("s1" => 1, "s2" => 2, "s3" => 1,  "s4" => 1, "s5" => 4, "s6" => 1, "s7" => 1),
	//"mac" => array ("s1" => 1, "s2" => 1, "s3" => 1,  "s4" => 1, "s5" => 1, "s6" => 1, "s7" => 1),
	"mac" => array ("s1" => 1, "s2" => 1, "s7" => 1),
	"unx" => array ("s1" => 1, "s2" => 1, "s3" => 1,  "s4" => 1, "s5" => 1, "s6" => 1, "s7" => 1, "s8" => 1),
	);

// set it here for now but later on may changes depending on what "Chapter" is being processed
$DocNameSpace = 100;

// Read the database then build the document map
$DataBase = DBConnect ($MySqlUser, $MySqlPswd);
$Pages = GatherTOCfiles ($DataBase, $DocNameSpace, $DocSetPageTitle);
$DocMap = BuildDocMap ($Pages, $DocSetPageTitle, $FileBrand);
CompleteDocMap ($DocMap);

if ($Test) {
	var_dump ($DocMap);
	exit (1);
	}

// BEGIN outside loop
$Section = 1;
foreach ($Chapters as $Chapter) {
	// the tutorial and platform specific "Chapters" get the same processing
	// the reference is different
	if ($Chapter != "ref") {
		while ($Section <= count ($Sections[$Chapter])) {
			// special temporarily processing a trucncated mac doc set
			if ($Chapter == "mac" && $Section == 3) {
				$Section = 7;
				}
			$Index = "s".$Section;
			$PageTitles = buildTitlePageArray ($BaseName[$Chapter], $Section, $Sections[$Chapter][$Index]);

			// The 'html' page header
			$DataBase = DBConnect ($MySqlUser, $MySqlPswd);
			$Row = ReadPage ($DataBase, $DocNameSpace, "Page_Header");

			// Look up the local filename in the DocMap
			$LocalFilename = LookupLocalFN ($PageTitles[0], $DocMap);

			// Open a file and 'append' to the previous contents
			$Images = fopen ("ImageManifest", "a") or die ("Could not open ImageManifest\n");

			// Open a file and 'overwrite' the previous contents
			$HtmlOut = fopen ("documentation/".$FileBrand."/".$LocalFilename.".html", "wt") or die ("Could not open HTML output\n");

			foreach ($Row as $Page) {
				$Page = FixTags ($Page, $PageTitles[0], $DocMap, $Platform, $Images);
				fwrite ($HtmlOut, $Page);
				}

			// Write the opening 'Page' <div> tag
			fwrite ($HtmlOut, "<div class=\"Page\">\n\n");

			// Generate the fixed panel entries
			$FixedPanel = BuildPageFP ($LocalFilename, $DocMap, "LongView");
			fwrite ($HtmlOut, $FixedPanel);

			// Write the opening 'Content' <div> tag
			fwrite ($HtmlOut, "<div class=\"Content\">\n");

			// the content header
			$DataBase = DBConnect ($MySqlUser, $MySqlPswd);
			$Row = ReadPage ($DataBase, $DocNameSpace, "Content_Header_Footer");
			foreach ($Row as $Page) {
				$Page = FixTags ($Page, $PageTitles[0], $DocMap, $Platform, $Images);
				fwrite ($HtmlOut, $Page);
				}

			// BEGIN inside loop
			// concatenate the files (sections) together
			foreach ( $PageTitles as $WikiTitle ) {
				echo "Processing: ".$WikiTitle."\n";
				$DataBase = DBConnect ($MySqlUser, $MySqlPswd);
				$Row = ReadPage ($DataBase, $DocNameSpace, $WikiTitle);
				foreach ($Row as $Page) {
					$Page = FixTags ($Page, $WikiTitle, $DocMap, $Platform, $Images);
					fwrite ($HtmlOut, $Page."\n");
					}
				} // END inside loop

			$ClosePage = "</div>\n\n</div>\n</body>\n</html>\n";
			fwrite ($HtmlOut, $ClosePage);
			fclose ($HtmlOut);
			fclose ($Images);
			$Section++;
			} // END outside loop
		$Section = 1;
		}
	else {
		$ndx = 0;
		// just the pages in the Reference namespace
		// $MapEntry->LocalFN equates to sections
		foreach ($DocMap as $MapEntry) {
			if ($MapEntry->getWikiNS() == "Reference" && $MapEntry->getWikiFN() != "Reference_Table_of_Contents") {
				$RefSectionsRaw[$ndx] = $MapEntry->getLocalFN();
				$RefPagesRaw[$ndx++] = $MapEntry->getWikiFN()."|".$MapEntry->getLocalFN();
				}
			}

		$RefPages = array_unique ($RefPagesRaw);
		$RefSections = array_unique ($RefSectionsRaw);
		$Section = 1;

		while ($Section <= count ($RefSections)) {
			echo "Processing: Reference_Section_".$Section."\n";
			// The 'html' page header
			$DataBase = DBConnect ($MySqlUser, $MySqlPswd);
			$Row = ReadPage ($DataBase, $DocNameSpace, "Page_Header");

			// Set the local filename
			$LocalFilename = "r3_".$Section;

			// Open a file and 'append' to the previous contents
			$Images = fopen ("ImageManifest", "a") or die ("Could not open ImageManifest\n");

			// Open a file and 'overwrite' the previous contents
			$HtmlOut = fopen ("documentation/".$FileBrand."/".$LocalFilename.".html", "wt") or die ("Could not open HTML output\n");

			foreach ($Row as $Page) {
				$Page = FixTags ($Page, "Reference Section ".$Section, $DocMap, $Platform, $Images);
				fwrite ($HtmlOut, $Page);
				}

			// Write the opening 'Page' <div> tag
			fwrite ($HtmlOut, "<div class=\"Page\">\n\n");

			// Generate the fixed panel entries
			$FixedPanel = BuildPageFP ($LocalFilename, $DocMap, "LongView");
			fwrite ($HtmlOut, $FixedPanel);

			// Write the opening 'Content' <div> tag
			fwrite ($HtmlOut, "<div class=\"Content\">\n");

			// the content header
			$DataBase = DBConnect ($MySqlUser, $MySqlPswd);
			$Row = ReadPage ($DataBase, $DocNameSpace, "Content_Header_Footer");
			foreach ($Row as $Page) {
				$Page = FixTags ($Page, "Reference Section ".$Section, $DocMap, $Platform, $Images);
				fwrite ($HtmlOut, $Page);
				}

			$DocNameSpace = 108;
			// concatenate files here
			foreach ($RefPages as $RefPage) {
				$RefPageEntry = explode ("|", $RefPage);
				$DataBase = DBConnect ($MySqlUser, $MySqlPswd);
				if ($RefPageEntry[1] == "r3_".$Section) {
					$DataBase = DBConnect ($MySqlUser, $MySqlPswd);
					$Row = ReadPage ($DataBase, $DocNameSpace, $RefPageEntry[0]);
					if ($Row) {
						foreach ($Row as $Page) {
							$RefPageEntry[0] = flipRefPageName ($RefPageEntry[0]);
							$Page = "==".$RefPageEntry[0]."==\n".$Page;
							$Page = FixTags ($Page, $RefPageEntry[0], $DocMap, $Platform, $Images);
							fwrite ($HtmlOut, $Page."\n");
							}
						}
					else {
						echo "Couldn't find: ".$RefPageEntry[0]." in wikidb.\n";
						}
					} // end if ($Row)
				} // end foreach ($RefPages)

			$ClosePage = "</div>\n\n</div>\n</body>\n</html>\n";
			fwrite ($HtmlOut, $ClosePage);
			fclose ($HtmlOut);
			fclose ($Images);

			$Section++;
			$DocNameSpace = 100;
			} // while
		} // the last else	
	} // outer foreach

?>
